package com.elitesland.org.repo;

import com.elitesland.org.entity.EmployeeDO;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.querydsl.QuerydslPredicateExecutor;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Optional;

@Repository
public interface EmployeeRepo extends JpaRepository<EmployeeDO, Long>, QuerydslPredicateExecutor<EmployeeDO> {

    /**
     * 根据一个或多个部门记录ID，返回关联的所有的雇员信息
     *
     * @param deptIds 部门记录ID集合
     * @return 雇员集合
     */
    List<EmployeeDO> findAllByBuIdIn(List<Long> deptIds);

    List<EmployeeDO> findAllByIdIn(List<Long> ids);

    /**
     * 根据系统账号信息，返回对应的雇员信息
     *
     * @param sysUserName 系统账号
     * @return 雇员信息
     */
    Optional<EmployeeDO> findBySysUserName(String sysUserName);

    Optional<EmployeeDO> findByEmpNo(String empNo);

    Optional<EmployeeDO> findByIdNotAndEmpNo(Long id, String empNo);

    List<EmployeeDO> findAllByReportToPathLike(String reportToPath);

    /**
     * 根据当前登录人id，获取员工信息
     * @param userId 当前登录人id
     * @return 员工信息
     */
    List<EmployeeDO> findByTenantId(Long userId);

    List<EmployeeDO> findAllByReportToId(Long id);
}
